@@ -1,5 +1,5 @@
 "guiInputTask1" <-
-function()
+function(taskWindow)
 {
   
   ### Initialize Variables ###
@@ -78,7 +78,7 @@ function()
       
       #update n in menu bar
       tkdelete(topMenu,0,1)  
-      tkadd(topMenu,"cascade",label=paste("#Interim times: n=",as.character(n)),menu=nMenu)
+      tkadd(topMenu,"cascade",label=paste("#Interim times: K=",as.character(n)),menu=nMenu)
       
       ### equally or unequally spaced times? get it from the checkbox ###
       equallySpacedTimesInput <- as.logical(as.numeric(tclvalue(equallySpacedTimesCheckBoxValue)))
@@ -179,7 +179,10 @@ tkgrid.remove(listOfTimePointLabel.unequalTimes[[i]],listOfEntries.unequalTimes[
   }#end <--*function()*
       
   ##############################################################
-  # function handles a click on checkbox for second time scale #
+  # function handles a click on checkbox for second time scale 
+  # 
+  # ATTENTION: this feature of a second time scale is currently NOT used!
+  #
   ##############################################################  
   onCheckBoxSecondTimeScale <- function()
   {
@@ -604,7 +607,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
     if(readyForCalculate)
     {
       calculateTask1(n,t,t2,equallySpacedTimesInput,secondTimeScaleIsUsedInput, BoundsSymmetry, c(alpha1,alpha2),
-                     c(phi1,phi2), c(function1,function2),TruncateBoundsInput)
+                     c(phi1,phi2), c(function1,function2),TruncateBoundsInput, taskWindow)
     }
     else
     {
@@ -612,7 +615,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
     }
   }
   
- 
+
 
 #######################################################################################################
 #################------------------------------------------------------------------####################
@@ -621,7 +624,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
 #######################################################################################################  
   
   #Set Toplevel
-  task1 <- tktoplevel()
+  task1 <- tktoplevel(taskWindow)
   tkwm.title(task1,"-1- Compute bounds")
   
   #Define main Frame
@@ -635,7 +638,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   #create pull down menu to select interim analyses from n==1 to n==25(=nMax)
   topMenu <- tkmenu(task1)
   tkconfigure(task1,menu=topMenu)
-  nMenu <- tkmenu(topMenu,tearoff=FALSE,background="grey",activebackground="green")
+  nMenu <- tkmenu(topMenu,tearoff=FALSE,background="grey",activebackground="red")
   tkadd(nMenu,"command",label="1",command=function() onChangeInterimAnalyses(1))
   tkadd(nMenu,"command",label="2",command=function() onChangeInterimAnalyses(2))
   tkadd(nMenu,"command",label="3",command=function() onChangeInterimAnalyses(3))
@@ -661,7 +664,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   tkadd(nMenu,"command",label="23",command=function() onChangeInterimAnalyses(23))
   tkadd(nMenu,"command",label="24",command=function() onChangeInterimAnalyses(24))
   tkadd(nMenu,"command",label="25",command=function() onChangeInterimAnalyses(25))
-  tkadd(topMenu,"cascade",label=paste("#Interim times: n= ",as.character(n)),menu=nMenu)
+  tkadd(topMenu,"cascade",label=paste("#Interim times: K= ",as.character(n)),menu=nMenu)
   
   tkgrid(tklabel(InputTask1,text="")) # Blank line
    
@@ -698,7 +701,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   equallyTimesBoxLabel<-tklabel(equallySpacedLabelFrame,text="Equally Spaced Times")
   secondTimesBoxLabel<-tklabel(secondTimesLabelFrame,text="Use Second Time Scale")
   tkgrid(equallyTimesBoxLabel,equallySpacedTimesCheckBox)
-  tkgrid(secondTimesBoxLabel,secondTimeScaleIsUsedCheckBox)
+  # tkgrid(secondTimesBoxLabel,secondTimeScaleIsUsedCheckBox) - this feature is currently removed
   tkgrid(equallySpacedTimesFrame,secondTimesFrame,sticky="nw")
   tkgrid(equallySpacedLabelFrame,sticky="nw")
   tkgrid(secondTimesLabelFrame,sticky="nw")
@@ -741,10 +744,10 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   symmetricBoundsFrame<-tkframe(alphaAndFunctionsFrame,relief="groove",borderwidth=0)
   nonSymmetricBoundsFrame<-tkframe(alphaAndFunctionsFrame,relief="groove",borderwidth=0)
   
-  ##Default alpha1==0.05, alpha2==0
+  ##Default alpha1==0.05, alpha2==0.025
   alpha1of1 <- tclVar(as.character(alphaInput))
-  alpha1of2 <- tclVar(as.character(alphaInput))
-  alpha2of2 <- tclVar(as.character("0"))
+  alpha1of2 <- tclVar(as.character("0.025"))
+  alpha2of2 <- tclVar(as.character("0.025"))
   
   #########################################################
   ### case symmetric bounds or one-sided test (default) ###
@@ -762,7 +765,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   functionLabel1of1<-tklabel(functionsFrame1of1,text="What function should be used?")
   listBoxFunction1of1<-tklistbox(functionsFrame1of1,height=5,width=30,selectmode="single",background="grey")
   functionChoice1of1 <- c("(1) O'Brien-Fleming Type","(2) Pocock Type",
-    "(3) Power family: alpha* t^phi","(4) Hwang-Shih-DeCani fammily","(5) Pocock - the real Pocock Bounds")
+    "(3) Power family: alpha* t^phi","(4) Hwang-Shih-DeCani family","(5) Exact Pocock Bounds")
   for (i in (1:5))
   {
     tkinsert(listBoxFunction1of1,"end",functionChoice1of1[i])
@@ -825,7 +828,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   functionLabel1of2<-tklabel(functionsFrame1of2,text="Choose Function for UPPER Bounds")
   listBoxFunction1of2<-tklistbox(functionsFrame1of2,height=5,width=30,selectmode="single",background="grey")
   functionChoice1of2 <- c("(1) O'Brien-Fleming Type","(2) Pocock Type",
-    "(3) Power family: alpha* t^phi","(4) Hwang-Shih-DeCani fammily","(5) Pocock - the real Pocock Bounds")
+    "(3) Power family: alpha* t^phi","(4) Hwang-Shih-DeCani family","(5) Pocock - the real Pocock Bounds")
   for (i in (1:5))
   {
     tkinsert(listBoxFunction1of2,"end",functionChoice1of2[i])
@@ -844,7 +847,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   functionLabel2of2<-tklabel(functionsFrame2of2,text="Choose Function for LOWER Bounds")
   listBoxFunction2of2<-tklistbox(functionsFrame2of2,height=5,width=30,selectmode="single",background="grey")
   functionChoice2of2 <- c("(1) O'Brien-Fleming Type","(2) Pocock Type",
-    "(3) Power family: alpha* t^phi","(4) Hwang-Shih-DeCani fammily","(5) Pocock - the real Pocock Bounds")
+    "(3) Power family: alpha* t^phi","(4) Hwang-Shih-DeCani family","(5) Pocock - the real Pocock Bounds")
   for (i in (1:5))
   {
     tkinsert(listBoxFunction2of2,"end",functionChoice2of2[i])
@@ -890,7 +893,7 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   tkgrid(tklabel(nonSymmetricBoundsFrame,text="")) # Blank line
  
   ################################################################# 
- 
+
   ###Truncate Bounds?###
   TruncateBoundsFrame <- tkframe(InputTask1,relief="groove",borderwidth=0)
   TruncateLabelFrame <- tkframe(TruncateBoundsFrame,relief="groove",borderwidth=0)
@@ -917,11 +920,26 @@ tkgrid.remove(listOfTimePointLabel.secondTimes[[i]],listOfEntries.secondTimes[[i
   ##put Overall Frame
   tkgrid(InputTask1)
   
+  #frame for the buttons
+  buttonFrame<-tkframe(task1,relief="groove",borderwidth=0)
   
   #create and put button for calculating
-  calculate.button <-tkbutton(task1,text=" CALCULATE ",command=OnCalculateInputTask1)
-  tkgrid(calculate.button,sticky="we")
+  calculate.button <-tkbutton(buttonFrame,text=" CALCULATE ",command=OnCalculateInputTask1)
+
+  # function handles click onto button to Cancel i.e. close current window
+  onCancel <- function()
+  {
+   tkdestroy(task1)
+  }
+  cancel.button <-tkbutton(buttonFrame,text=" Cancel ",command=onCancel)
   
+  # grid buttons
+  tkgrid( tklabel(buttonFrame, text=""))   #blank line
+  tkgrid(calculate.button, tklabel(buttonFrame, text="            "),
+         cancel.button, sticky="we" )
+  tkgrid( tklabel(buttonFrame, text=""))   #blank line
+  tkgrid(buttonFrame)
+
   tkfocus(task1)
 
 }
